MImix(results, ...)
"MImix"(results,variances,weights = 1/length(results), percentiles = c(0.025, 0.5, 0.975), ...)results is a list of parameter vectors,
variances should be the corresponding variance-covariance
matricesresults argument in the default method may be either a list of
parameter vectors or a list of objects that have coef and
vcov methods. In the former case a list of variance-covariance
matrices must be supplied as the second argument. This corresponds to the same
structure that is used by MIcombine in the mitools package.
### See help(diaph.data) for example
Run the code above in your browser using DataLab